# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('stacks_snippet', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='snippet',
            name='display_title',
            field=models.CharField(help_text='An optional displayed-to-the-user title of this content.', max_length=100, verbose_name='Display Title', blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Snippet',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_modified', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(help_text='The name of this HTML snippet. For internal use only.', max_length=100, verbose_name='Name')),
                ('snippet', models.TextField(help_text='The snippet of HTML.', verbose_name='HTML Snippet')),
            ],
        ),
    ]



from django.utils.safestring import mark_safe

from rest_framework import serializers
from textplusstuff.serializers import ExtraContextSerializerMixIn

from .models import Snippet


class SnippetSerializer(ExtraContextSerializerMixIn,
                        serializers.ModelSerializer):
    snippet = serializers.SerializerMethodField()

    class Meta:
        model = Snippet
        fields = (
            'name',
            'snippet'
        )

    def get_snippet(self, obj):
        return mark_safe(obj.snippet)



from django.contrib import admin

from textplusstuff.admin import TextPlusStuffRegisteredModelAdmin

from .models import Snippet


class SnippetAdmin(TextPlusStuffRegisteredModelAdmin):
    search_fields = ['name']


admin.site.register(Snippet, SnippetAdmin)



from django.db import models
from django.utils.translation import ugettext_lazy as _


class Snippet(models.Model):
    """Represents a snippet of HTML."""
    date_created = models.DateTimeField(
        auto_now_add=True
    )
    date_modified = models.DateTimeField(
        auto_now=True
    )
    name = models.CharField(
        _('Name'),
        max_length=100,
        help_text=_("The name of this HTML snippet. For internal use only.")
    )
    display_title = models.CharField(
        _('Display Title'),
        max_length=100,
        help_text=_(
            'An optional displayed-to-the-user title of this content.'
        ),
        blank=True
    )
    snippet = models.TextField(
        _('HTML Snippet'),
        help_text=_("The snippet of HTML.")
    )

    def __unicode__(self):
        return self.name



from textplusstuff import registry

from .models import Snippet
from .serializers import SnippetSerializer


class SnippetStuff(registry.ModelStuff):
    queryset = Snippet.objects.all()
    verbose_name = 'HTML Snippet'
    verbose_name_plural = 'HTML Snippets'
    description = 'Add a HTML Snippet'
    serializer_class = SnippetSerializer
    renditions = [
        registry.Rendition(
            short_name='full_width',
            verbose_name="Snippet Full Width",
            description='Displays an HTML Snippet that spans the full '
                        'width of the page.',
            path_to_template='stacks_snippet/snippet-full_width.html',
            rendition_type='block'
        ),
    ]
    list_display = ('id', 'name')

registry.stuff_registry.add_modelstuff(
    Snippet,
    SnippetStuff,
    groups=['stacks', ]
)
